@@ -3,9 +3,11 @@ Main interface for connectparticipant service type definitions.
 
 Usage::
 
-    from mypy_boto3.connectparticipant.type_defs import ConnectionCredentialsTypeDef
+    ```python
+    from mypy_boto3_connectparticipant.type_defs import ConnectionCredentialsTypeDef
 
     data: ConnectionCredentialsTypeDef = {...}
+    ```
 """
 import sys
 from typing import List
@@ -14,6 +16,9 @@ if sys.version_info >= (3, 8):
     from typing import Literal
 else:
     from typing_extensions import Literal
+
+import sys
+
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
@@ -22,9 +27,9 @@ else:
 
 __all__ = (
     "ConnectionCredentialsTypeDef",
+    "ItemTypeDef",
     "WebsocketTypeDef",
     "CreateParticipantConnectionResponseTypeDef",
-    "ItemTypeDef",
     "GetTranscriptResponseTypeDef",
     "SendEventResponseTypeDef",
     "SendMessageResponseTypeDef",
@@ -35,14 +40,6 @@ ConnectionCredentialsTypeDef = TypedDict(
     "ConnectionCredentialsTypeDef", {"ConnectionToken": str, "Expiry": str}, total=False
 )
 
-WebsocketTypeDef = TypedDict("WebsocketTypeDef", {"Url": str, "ConnectionExpiry": str}, total=False)
-
-CreateParticipantConnectionResponseTypeDef = TypedDict(
-    "CreateParticipantConnectionResponseTypeDef",
-    {"Websocket": WebsocketTypeDef, "ConnectionCredentials": ConnectionCredentialsTypeDef},
-    total=False,
-)
-
 ItemTypeDef = TypedDict(
     "ItemTypeDef",
     {
@@ -58,9 +55,17 @@ ItemTypeDef = TypedDict(
     total=False,
 )
 
+WebsocketTypeDef = TypedDict("WebsocketTypeDef", {"Url": str, "ConnectionExpiry": str}, total=False)
+
+CreateParticipantConnectionResponseTypeDef = TypedDict(
+    "CreateParticipantConnectionResponseTypeDef",
+    {"Websocket": "WebsocketTypeDef", "ConnectionCredentials": "ConnectionCredentialsTypeDef"},
+    total=False,
+)
+
 GetTranscriptResponseTypeDef = TypedDict(
     "GetTranscriptResponseTypeDef",
-    {"InitialContactId": str, "Transcript": List[ItemTypeDef], "NextToken": str},
+    {"InitialContactId": str, "Transcript": List["ItemTypeDef"], "NextToken": str},
     total=False,
 )
 
